/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.service.http;

import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.util.MethodHandler;
import com.liferay.portal.kernel.util.MethodKey;
import com.liferay.portal.security.auth.HttpPrincipal;
import com.liferay.portal.service.RoleServiceUtil;

/**
 * <a href="RoleServiceHttp.java.html"><b><i>View Source</i></b></a>
 *
 * <p>
 * ServiceBuilder generated this class. Modifications in this class will be
 * overwritten the next time is generated.
 * </p>
 *
 * <p>
 * This class provides a HTTP utility for the
 * {@link com.liferay.portal.service.RoleServiceUtil} service utility. The
 * static methods of this class calls the same methods of the service utility.
 * However, the signatures are different because it requires an additional
 * {@link com.liferay.portal.security.auth.HttpPrincipal} parameter.
 * </p>
 *
 * <p>
 * The benefits of using the HTTP utility is that it is fast and allows for
 * tunneling without the cost of serializing to text. The drawback is that it
 * only works with Java.
 * </p>
 *
 * <p>
 * Set the property <b>tunnel.servlet.hosts.allowed</b> in portal.properties to
 * configure security.
 * </p>
 *
 * <p>
 * The HTTP utility is only generated for remote services.
 * </p>
 *
 * @author    Brian Wing Shun Chan
 * @see       RoleServiceSoap
 * @see       com.liferay.portal.security.auth.HttpPrincipal
 * @see       com.liferay.portal.service.RoleServiceUtil
 * @generated
 */
public class RoleServiceHttp {
	public static com.liferay.portal.model.Role addRole(
		HttpPrincipal httpPrincipal, java.lang.String name,
		java.lang.String description, int type)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"addRole", _addRoleParameterTypes0);

			MethodHandler methodHandler = new MethodHandler(methodKey, name,
					description, type);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return (com.liferay.portal.model.Role)returnObj;
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static void addUserRoles(HttpPrincipal httpPrincipal, long userId,
		long[] roleIds)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"addUserRoles", _addUserRolesParameterTypes1);

			MethodHandler methodHandler = new MethodHandler(methodKey, userId,
					roleIds);

			try {
				TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static void deleteRole(HttpPrincipal httpPrincipal, long roleId)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"deleteRole", _deleteRoleParameterTypes2);

			MethodHandler methodHandler = new MethodHandler(methodKey, roleId);

			try {
				TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static com.liferay.portal.model.Role getGroupRole(
		HttpPrincipal httpPrincipal, long companyId, long groupId)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"getGroupRole", _getGroupRoleParameterTypes3);

			MethodHandler methodHandler = new MethodHandler(methodKey,
					companyId, groupId);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return (com.liferay.portal.model.Role)returnObj;
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static java.util.List<com.liferay.portal.model.Role> getGroupRoles(
		HttpPrincipal httpPrincipal, long groupId)
		throws com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"getGroupRoles", _getGroupRolesParameterTypes4);

			MethodHandler methodHandler = new MethodHandler(methodKey, groupId);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return (java.util.List<com.liferay.portal.model.Role>)returnObj;
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static com.liferay.portal.model.Role getRole(
		HttpPrincipal httpPrincipal, long roleId)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"getRole", _getRoleParameterTypes5);

			MethodHandler methodHandler = new MethodHandler(methodKey, roleId);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return (com.liferay.portal.model.Role)returnObj;
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static com.liferay.portal.model.Role getRole(
		HttpPrincipal httpPrincipal, long companyId, java.lang.String name)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"getRole", _getRoleParameterTypes6);

			MethodHandler methodHandler = new MethodHandler(methodKey,
					companyId, name);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return (com.liferay.portal.model.Role)returnObj;
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static java.util.List<com.liferay.portal.model.Role> getUserGroupGroupRoles(
		HttpPrincipal httpPrincipal, long userId, long groupId)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"getUserGroupGroupRoles",
					_getUserGroupGroupRolesParameterTypes7);

			MethodHandler methodHandler = new MethodHandler(methodKey, userId,
					groupId);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return (java.util.List<com.liferay.portal.model.Role>)returnObj;
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static java.util.List<com.liferay.portal.model.Role> getUserGroupRoles(
		HttpPrincipal httpPrincipal, long userId, long groupId)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"getUserGroupRoles", _getUserGroupRolesParameterTypes8);

			MethodHandler methodHandler = new MethodHandler(methodKey, userId,
					groupId);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return (java.util.List<com.liferay.portal.model.Role>)returnObj;
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static java.util.List<com.liferay.portal.model.Role> getUserRelatedRoles(
		HttpPrincipal httpPrincipal, long userId,
		java.util.List<com.liferay.portal.model.Group> groups)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"getUserRelatedRoles", _getUserRelatedRolesParameterTypes9);

			MethodHandler methodHandler = new MethodHandler(methodKey, userId,
					groups);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return (java.util.List<com.liferay.portal.model.Role>)returnObj;
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static java.util.List<com.liferay.portal.model.Role> getUserRoles(
		HttpPrincipal httpPrincipal, long userId)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"getUserRoles", _getUserRolesParameterTypes10);

			MethodHandler methodHandler = new MethodHandler(methodKey, userId);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return (java.util.List<com.liferay.portal.model.Role>)returnObj;
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static boolean hasUserRole(HttpPrincipal httpPrincipal, long userId,
		long companyId, java.lang.String name, boolean inherited)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"hasUserRole", _hasUserRoleParameterTypes11);

			MethodHandler methodHandler = new MethodHandler(methodKey, userId,
					companyId, name, inherited);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return ((Boolean)returnObj).booleanValue();
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static boolean hasUserRoles(HttpPrincipal httpPrincipal,
		long userId, long companyId, java.lang.String[] names, boolean inherited)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"hasUserRoles", _hasUserRolesParameterTypes12);

			MethodHandler methodHandler = new MethodHandler(methodKey, userId,
					companyId, names, inherited);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return ((Boolean)returnObj).booleanValue();
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static void unsetUserRoles(HttpPrincipal httpPrincipal, long userId,
		long[] roleIds)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"unsetUserRoles", _unsetUserRolesParameterTypes13);

			MethodHandler methodHandler = new MethodHandler(methodKey, userId,
					roleIds);

			try {
				TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	public static com.liferay.portal.model.Role updateRole(
		HttpPrincipal httpPrincipal, long roleId, java.lang.String name,
		java.util.Map<java.util.Locale, java.lang.String> localeTitlesMap,
		java.lang.String description, java.lang.String subtype)
		throws com.liferay.portal.PortalException,
			com.liferay.portal.SystemException {
		try {
			MethodKey methodKey = new MethodKey(RoleServiceUtil.class.getName(),
					"updateRole", _updateRoleParameterTypes14);

			MethodHandler methodHandler = new MethodHandler(methodKey, roleId,
					name, localeTitlesMap, description, subtype);

			Object returnObj = null;

			try {
				returnObj = TunnelUtil.invoke(httpPrincipal, methodHandler);
			}
			catch (Exception e) {
				if (e instanceof com.liferay.portal.PortalException) {
					throw (com.liferay.portal.PortalException)e;
				}

				if (e instanceof com.liferay.portal.SystemException) {
					throw (com.liferay.portal.SystemException)e;
				}

				throw new com.liferay.portal.SystemException(e);
			}

			return (com.liferay.portal.model.Role)returnObj;
		}
		catch (com.liferay.portal.SystemException se) {
			_log.error(se, se);

			throw se;
		}
	}

	private static Log _log = LogFactoryUtil.getLog(RoleServiceHttp.class);
	private static final Class<?>[] _addRoleParameterTypes0 = new Class[] {
			java.lang.String.class, java.lang.String.class, int.class
		};
	private static final Class<?>[] _addUserRolesParameterTypes1 = new Class[] {
			long.class, long[].class
		};
	private static final Class<?>[] _deleteRoleParameterTypes2 = new Class[] {
			long.class
		};
	private static final Class<?>[] _getGroupRoleParameterTypes3 = new Class[] {
			long.class, long.class
		};
	private static final Class<?>[] _getGroupRolesParameterTypes4 = new Class[] {
			long.class
		};
	private static final Class<?>[] _getRoleParameterTypes5 = new Class[] {
			long.class
		};
	private static final Class<?>[] _getRoleParameterTypes6 = new Class[] {
			long.class, java.lang.String.class
		};
	private static final Class<?>[] _getUserGroupGroupRolesParameterTypes7 = new Class[] {
			long.class, long.class
		};
	private static final Class<?>[] _getUserGroupRolesParameterTypes8 = new Class[] {
			long.class, long.class
		};
	private static final Class<?>[] _getUserRelatedRolesParameterTypes9 = new Class[] {
			long.class, java.util.List.class
		};
	private static final Class<?>[] _getUserRolesParameterTypes10 = new Class[] {
			long.class
		};
	private static final Class<?>[] _hasUserRoleParameterTypes11 = new Class[] {
			long.class, long.class, java.lang.String.class, boolean.class
		};
	private static final Class<?>[] _hasUserRolesParameterTypes12 = new Class[] {
			long.class, long.class, java.lang.String[].class, boolean.class
		};
	private static final Class<?>[] _unsetUserRolesParameterTypes13 = new Class[] {
			long.class, long[].class
		};
	private static final Class<?>[] _updateRoleParameterTypes14 = new Class[] {
			long.class, java.lang.String.class, java.util.Map.class,
			java.lang.String.class, java.lang.String.class
		};
}